package de.intevation.flys.client.server;

import org.w3c.dom.Document;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;

import de.intevation.artifacts.common.utils.ClientProtocolUtils;

import de.intevation.artifacts.httpclient.exceptions.ConnectionException;
import de.intevation.artifacts.httpclient.http.HttpClient;
import de.intevation.artifacts.httpclient.http.HttpClientImpl;

import de.intevation.flys.client.shared.exceptions.ServerException;
import de.intevation.flys.client.shared.model.Artifact;
import de.intevation.flys.client.client.services.ArtifactService;


/**
 * This interface provides artifact specific services as CREATE, DESCRIBE, FEED,
 * ADVANCE and OUT.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ArtifactServiceImpl
extends      RemoteServiceServlet
implements   ArtifactService
{
    /** The error message key that is thrown if an error occured while artifact
     * creation.*/
    public static final String ERROR_CREATE_ARTIFACT = "error_create_artifact";


    public Artifact create(
        String serverUrl,
        String locale,
        String factory,
        String uuid,
        String ids)
    throws ServerException
    {
        System.out.println("ArtifactServiceImpl.create");

        Document create = null;

        if (uuid != null && uuid.length() > 0) {
            create = ClientProtocolUtils.newCreateDocument(factory, uuid, ids);
        }
        else {
            create = ClientProtocolUtils.newCreateDocument(factory);
        }

        HttpClient client = new HttpClientImpl(serverUrl, locale);

        try {
            return (Artifact) client.create(create, new FLYSArtifactCreator());
        }
        catch (ConnectionException ce) {
            System.err.println(ce.getLocalizedMessage());
        }

        throw new ServerException(ERROR_CREATE_ARTIFACT);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
